@@ -1,8 +1,8 @@
 /* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 
-/* Copyright (C) 2018-2022 Hans Petter Jansson
+/* Copyright (C) 2018-2023 Hans Petter Jansson
  *
- * This file is part of Chafa, a program that turns images into character art.
+ * This file is part of Chafa, a program that shows pictures on text terminals.
  *
  * Chafa is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published
@@ -42,12 +42,20 @@ void chafa_canvas_unref (ChafaCanvas *canvas);
 CHAFA_AVAILABLE_IN_ALL
 const ChafaCanvasConfig *chafa_canvas_peek_config (ChafaCanvas *canvas);
 
+CHAFA_AVAILABLE_IN_1_14
+void chafa_canvas_set_placement (ChafaCanvas *canvas, ChafaPlacement *placement);
+
 CHAFA_AVAILABLE_IN_1_2
 void chafa_canvas_draw_all_pixels (ChafaCanvas *canvas, ChafaPixelType src_pixel_type,
                                    const guint8 *src_pixels,
                                    gint src_width, gint src_height, gint src_rowstride);
 CHAFA_AVAILABLE_IN_1_6
 GString *chafa_canvas_print (ChafaCanvas *canvas, ChafaTermInfo *term_info);
+CHAFA_AVAILABLE_IN_1_14
+void chafa_canvas_print_rows (ChafaCanvas *canvas, ChafaTermInfo *term_info,
+                              GString ***array_out, gint *array_len_out);
+CHAFA_AVAILABLE_IN_1_14
+gchar **chafa_canvas_print_rows_strv (ChafaCanvas *canvas, ChafaTermInfo *term_info);
 
 CHAFA_AVAILABLE_IN_1_8
 gunichar chafa_canvas_get_char_at (ChafaCanvas *canvas, gint x, gint y);
